﻿/// @file config.cpp
///
/// @brief 設定ファイル入出力
///
#include "config.h"
#include <wx/filename.h>
#include <wx/fileconf.h>

Config::Config()
{
	ini_file = _T("");

	// default value
	mFilePath = _T("");
	mNewLineAscii = 0;
	mNewLineUtf8 = 1;
	mIncludeBOM = false;
	mStartAddr = 2;

	SetDefaultFontName();
}

Config::~Config()
{
}

void Config::SetFileName(const wxString &file)
{
	ini_file = file;
}

void Config::Load()
{
	if (ini_file.IsEmpty()) return;

	// load ini file
	wxFileConfig *ini = new wxFileConfig(wxEmptyString,wxEmptyString,ini_file,wxEmptyString
		,wxCONFIG_USE_LOCAL_FILE | wxCONFIG_USE_RELATIVE_PATH | wxCONFIG_USE_NO_ESCAPE_CHARACTERS);

	int v;
	ini->Read(_T("Path"), &mFilePath, mFilePath);
	ini->Read(_T("NewLineAscii"), &v, mNewLineAscii); if(0 <= v && v <= 2) mNewLineAscii = v;
	ini->Read(_T("NewLineUtf8"), &v, mNewLineUtf8); if(0 <= v && v <= 2) mNewLineUtf8 = v;
	ini->Read(_T("IncludeBOM"), &mIncludeBOM, mIncludeBOM);
	ini->Read(_T("StartAddr"), &v, mStartAddr); if(0 <= v && v <= 3) mStartAddr = v;
	ini->Read(_T("FontName"), &mFontName, mFontName);
	ini->Read(_T("FontSize"), &v, mFontSize); if(1 <= v && v < 100) mFontSize = v;

	delete ini;
}

void Config::Load(const wxString &file)
{
	SetFileName(file);
	Load();
}

void Config::Save()
{
	if (ini_file.IsEmpty()) return;

	// save ini file
	wxFileConfig *ini = new wxFileConfig(wxEmptyString,wxEmptyString,ini_file,wxEmptyString
		,wxCONFIG_USE_LOCAL_FILE | wxCONFIG_USE_RELATIVE_PATH | wxCONFIG_USE_NO_ESCAPE_CHARACTERS);
	ini->Write(_T("Path"), mFilePath);
	ini->Write(_T("NewLineAscii"), mNewLineAscii);
	ini->Write(_T("NewLineUtf8"), mNewLineUtf8);
	ini->Write(_T("IncludeBOM"), mIncludeBOM);
	ini->Write(_T("StartAddr"), mStartAddr);
	ini->Write(_T("FontName"), mFontName);
	ini->Write(_T("FontSize"), mFontSize);
	// write
	delete ini;
}

void Config::SetDefaultFontName()
{
	mFontName = _T("");
	mFontSize = 10;
}
