﻿/// @file fileinfo.cpp
///
/// @brief ファイル情報
///
#include "fileinfo.h"

PsFileType::PsFileType() {
	flags = 0;
}
PsFileType::PsFileType(const PsFileType *new_type) {
	flags = new_type->flags;
	SetBasicType(new_type->basic_type);
	SetCharType(new_type->char_type);
	SetInternalName(new_type->internal_name);
}
PsFileType::PsFileType(const PsFileType &new_type) {
	flags = new_type.flags;
	SetBasicType(new_type.basic_type);
	SetCharType(new_type.char_type);
	SetInternalName(new_type.internal_name);
}
PsFileType &PsFileType::operator=(const PsFileType &src) {
	flags = src.flags;
	SetBasicType(src.basic_type);
	SetCharType(src.char_type);
	SetInternalName(src.internal_name);
	return *this;
}
void PsFileType::SetFlag(int flag_type, bool val) {
	if (val) flags |= flag_type;
	else flags &= ~flag_type;
}
bool PsFileType::GetFlag(int flag_type) {
	return (flags & flag_type) ? true : false;
}
void PsFileType::SetBasicType(const wxString &val) {
	basic_type = val;
	if (basic_type.IsEmpty()) {
		SetFlag(psExtendBasic, false);
	} else {
		SetFlag(psExtendBasic, true);
	}
}
void PsFileType::SetCharType(const wxString &val) {
	char_type = val;
	if (char_type.IsEmpty()) {
		SetFlag(psUTF8, false);
	} else {
		SetFlag(psUTF8, true);
	}
}
void PsFileType::SetInternalName(const wxString &val) {
	internal_name = val;
}

//
PsFileInfo::PsFileInfo() {
	start_pos = 0;
}
PsFileInfo::PsFileInfo(const PsFileInfo *new_info) {
	file_name = new_info->file_name;
	type = new_info->type;
	start_pos = new_info->start_pos;
}
PsFileInfo::PsFileInfo(const PsFileInfo &new_info) {
	file_name = new_info.file_name;
	type = new_info.type;
	start_pos = new_info.start_pos;
}
PsFileInfo &PsFileInfo::operator=(const PsFileInfo &src) {
	file_name = src.file_name;
	type = src.type;
	start_pos = src.start_pos;
	return *this;
}
