﻿/// @file fileinfo.h
///
/// @brief ファイル情報
///
#ifndef _FILEINFO_H_
#define _FILEINFO_H_

#include "common.h"
#include <wx/wx.h>
#include <wx/file.h>
#include <wx/filename.h>
#include <wx/dynarray.h>

/// ファイルタイプ
#define psBinary      0x00000000
#define psAscii       0x00000001
#define psUTF8        0x00000002
#define psUTF8BOM     0x00000004
#define psExtendBasic 0x00000008
#define psEncrypted   0x00000010

/// ファイルタイプ情報
class PsFileType {
private:
	int			flags;
	wxString	basic_type;
	wxString	char_type;
	wxString	internal_name;
public:
	PsFileType();
	PsFileType(const PsFileType *new_type);
	PsFileType(const PsFileType &new_type);
	PsFileType &operator=(const PsFileType &src);

	void SetFlag(int flag_type, bool val);
	bool GetFlag(int flag_type);
	void SetBasicType(const wxString &val);
	wxString &GetBasicType() { return basic_type; }
	void SetCharType(const wxString &val);
	wxString &GetCharType() { return char_type; }
	void SetInternalName(const wxString &val);
	wxString &GetInternalName() { return internal_name; }
};

/// ファイル情報
class PsFileInfo {
public:
	wxFile		file;
	wxFileName	file_name;
	PsFileType	type;
	int         start_pos;
public:
	PsFileInfo();
	PsFileInfo(const PsFileInfo *new_info);
	PsFileInfo(const PsFileInfo &new_info);
	PsFileInfo &operator=(const PsFileInfo &src);
};

#endif /* _FILEINFO_H_ */
